@@ -1114,8 +1114,7 @@ module_property(Module, Property) :-
 property_module(Property, Module) :-
     module_property(Property),
     (   Property = exported_operators(List)
-    ->  '$exported_ops'(Module, List, []),
-        List \== []
+    ->  '$exported_ops'(Module, List, [])
     ;   '$module_property'(Module, Property)
     ).
 
