@@ -3,7 +3,7 @@
     Author:        Jan Wielemaker
     E-mail:        J.Wielemaker@vu.nl
     WWW:           http://www.swi-prolog.org
-    Copyright (c)  2000-2019, University of Amsterdam
+    Copyright (c)  2000-2020, University of Amsterdam
                               VU University Amsterdam
 			      CWI, Amsterdam
     All rights reserved.
@@ -72,6 +72,10 @@
 #include <pthread.h>
 #endif
 
+#ifdef HAVE_CRT_EXTERNS_H
+#include <crt_externs.h>	/* _NSGetEnviron() on MacOS */
+#endif
+
 static atom_t ATOM_stdin;
 static atom_t ATOM_stdout;
 static atom_t ATOM_stderr;
@@ -331,7 +335,12 @@ parse_environment(term_t t, p_options *info, int pass)
 
 #ifndef __WINDOWS__
   if ( pass )
-  { extern char **environ;
+  {
+#ifdef HAVE__NSGETENVIRON
+    char **environ = *_NSGetEnviron();
+#else
+    extern char **environ;
+#endif
     char **e;
 
     for(e=environ; e && *e; e++)
