@@ -617,7 +617,7 @@ redo:
         PL_free(a->name);
       a->type = ATOM_TYPE_INVALID;
       a->name = "<race>";
-      MemoryBarrier();
+      MEMORY_BARRIER();
       a->references = 0;
       goto redo;
     }
@@ -665,8 +665,8 @@ static char *t_tracking;
 
 static int
 tracking(const Atom a)
-{ return /*a->type == &text_atom && */
-         strprefix(a->name, t_tracking);
+{ return ( a->type == &text_atom &&
+	   strcmp(a->name, t_tracking) == 0 );
 }
 
 
@@ -681,7 +681,7 @@ _PL_debug_register_atom(atom_t a,
   { Atom atom = fetchAtomArray(i);
     unsigned int refs;
 
-    refs = register_atom(atom);
+    refs = ATOM_REF_COUNT(register_atom(atom));
     if ( atomLogFd && tracking(atom) )
       Sfprintf(atomLogFd, "%s:%d: %s(): ++ (%d) for `%s' (#%d)\n",
 	       file, line, func, refs, atom->name, i);
@@ -921,7 +921,7 @@ destroyAtom(Atom a, Atom **buckets)
 
   a->name = "<reclaimed>";
   a->type = ATOM_TYPE_INVALID;
-  MemoryBarrier();
+  MEMORY_BARRIER();
   a->references = 0;
 
   index = indexAtom(a->atom);
